@@ -8,22 +8,35 @@
 #include "addonmodel.h"
 #include "config.h"
 #include "dbusprovider.h"
-#include "logging.h"
+#include "imconfig.h"
+#include "layoutprovider.h"
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KPluginFactory>
+#include <QDBusArgument>
+#include <QDBusPendingReply>
+#include <QDBusVariant>
 #include <QFileInfo>
 #include <QGuiApplication>
+#include <QKeyEvent>
+#include <QMap>
+#include <QObject>
+#include <QProcess>
 #include <QQuickItem>
 #include <QQuickRenderControl>
 #include <QQuickWindow>
 #include <QString>
+#include <QStringLiteral>
 #include <QVariantMap>
+#include <QWindowList>
+#include <Qt>
+#include <QtContainerFwd>
 #include <QtGlobal>
-#include <config.h>
+#include <fcitx-utils/key.h>
 #include <fcitx-utils/misc.h>
-#include <fcitx-utils/standardpath.h>
-#include <fcitx-utils/stringutils.h>
+#include <fcitx-utils/standardpaths.h>
+#include <fcitxqtdbustypes.h>
+#include <kquickconfigmodule.h>
 
 namespace fcitx::kcm {
 
@@ -54,44 +67,16 @@ QString maybeExtractExternalCommand(const QVariantMap &typeMap,
 }
 } // namespace
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 FcitxModule::FcitxModule(QObject *parent, const KPluginMetaData &metaData)
-    : FcitxKCMBase(parent, metaData),
-#elif defined(FCITX_USE_NEW_KDECLARATIVE)
-FcitxModule::FcitxModule(QObject *parent, const KPluginMetaData &metaData,
-                         const QVariantList &args)
-    : FcitxKCMBase(parent, metaData, args),
-#else
-FcitxModule::FcitxModule(QObject *parent, const QVariantList &args)
-    : FcitxKCMBase(parent, args),
-#endif
-      dbus_(new DBusProvider(this)),
+    : KQuickConfigModule(parent, metaData), dbus_(new DBusProvider(this)),
       imConfig_(new IMConfig(dbus_, IMConfig::Flatten, this)),
       layoutProvider_(new LayoutProvider(dbus_, this)),
       addonModel_(new FlatAddonModel(this)),
       addonProxyModel_(new AddonProxyModel(this)) {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    qmlRegisterType<FilteredIMModel>();
-    qmlRegisterType<IMProxyModel>();
-    qmlRegisterType<LanguageModel>();
-#else
     qmlRegisterAnonymousType<FilteredIMModel>("", 1);
     qmlRegisterAnonymousType<IMProxyModel>("", 1);
     qmlRegisterAnonymousType<LanguageModel>("", 1);
-#endif
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) &&                                  \
-    !defined(FCITX_USE_NEW_KDECLARATIVE)
-    KAboutData *about =
-        new KAboutData("kcm_fcitx5", i18n("Fcitx 5"), PROJECT_VERSION,
-                       i18n("Configure Fcitx 5"), KAboutLicense::GPL_V2,
-                       i18n("Copyright 2017 Xuetian Weng"), QString(),
-                       QString(), "wengxt@gmail.com");
-
-    about->addAuthor(i18n("Xuetian Weng"), i18n("Author"), "wengxt@gmail.com");
-
-    setAboutData(about);
-#endif
     addonProxyModel_->setSourceModel(addonModel_);
     addonProxyModel_->sort(0);
 
@@ -115,13 +100,14 @@ FcitxModule::FcitxModule(QObject *parent, const QVariantList &args)
                                                XKB_KEYMAP_COMPILE_NO_FLAGS));
     xkbState_.reset(xkb_state_new(xkbKeymap_.get()));
 
-    connect(this, &FcitxKCMBase::pagePushed, this, [this](QQuickItem *page) {
-        pages_[currentIndex() + 1] = page;
-        if (page->property("needsSave").isValid()) {
-            connect(page, SIGNAL(needsSaveChanged()), this,
-                    SLOT(pageNeedsSaveChanged()));
-        }
-    });
+    connect(this, &KQuickConfigModule::pagePushed, this,
+            [this](QQuickItem *page) {
+                pages_[currentIndex() + 1] = page;
+                if (page->property("needsSave").isValid()) {
+                    connect(page, SIGNAL(needsSaveChanged()), this,
+                            SLOT(pageNeedsSaveChanged()));
+                }
+            });
 }
 
 FcitxModule::~FcitxModule() {}
@@ -187,7 +173,7 @@ void configOptionToVariant(QVariantList &options,
         for (const auto &subOption : subOptions) {
             auto map = subOption.value<QVariantMap>();
             if (map["isSection"].toBool()) {
-                map["description"] = QString("%1 > %2").arg(
+                map["description"] = QStringLiteral("%1 > %2").arg(
                     option.description(), map["description"].toString());
                 options.append(map);
             } else {
@@ -230,7 +216,7 @@ void FcitxModule::pushConfigPage(const QString &title, const QString &uri) {
         return;
     }
     auto call = dbus_->controller()->GetConfig(uri);
-    auto watcher = new QDBusPendingCallWatcher(call, this);
+    auto *watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this,
             [this, uri, title](QDBusPendingCallWatcher *watcher) {
                 watcher->deleteLater();
@@ -286,7 +272,7 @@ void FcitxModule::loadAddon() {
         return;
     }
     auto call = dbus_->controller()->GetAddonsV2();
-    auto callwatcher = new QDBusPendingCallWatcher(call, this);
+    auto *callwatcher = new QDBusPendingCallWatcher(call, this);
     connect(callwatcher, &QDBusPendingCallWatcher::finished, this,
             [this](QDBusPendingCallWatcher *watcher) {
                 QDBusPendingReply<FcitxQtAddonInfoV2List> addons = *watcher;
@@ -303,13 +289,13 @@ void FcitxModule::saveAddon() {
         return;
     }
     FcitxQtAddonStateList list;
-    for (auto &enabled : addonModel_->enabledList()) {
+    for (const auto &enabled : addonModel_->enabledList()) {
         FcitxQtAddonState state;
         state.setUniqueName(enabled);
         state.setEnabled(true);
         list.append(state);
     }
-    for (auto &disabled : addonModel_->disabledList()) {
+    for (const auto &disabled : addonModel_->disabledList()) {
         FcitxQtAddonState state;
         state.setUniqueName(disabled);
         state.setEnabled(false);
@@ -324,10 +310,10 @@ void FcitxModule::saveAddon() {
 void FcitxModule::launchExternal(const QString &uri) {
     WId wid = 0;
     if (QGuiApplication::platformName() == "xcb") {
-        auto window = mainUi()->window();
+        auto *window = mainUi()->window();
         QWindow *actualWindow = window;
         if (window) {
-            auto renderWindow = QQuickRenderControl::renderWindowFor(window);
+            auto *renderWindow = QQuickRenderControl::renderWindowFor(window);
             if (renderWindow) {
                 actualWindow = renderWindow;
             }
@@ -354,7 +340,7 @@ bool FcitxModule::eventFilter(QObject *, QEvent *event) {
     if (event->type() == QEvent::KeyPress ||
         event->type() == QEvent::KeyRelease ||
         event->type() == QEvent::ShortcutOverride) {
-        auto keyEvent = static_cast<QKeyEvent *>(event);
+        auto *keyEvent = static_cast<QKeyEvent *>(event);
         key_ = Key(static_cast<KeySym>(keyEvent->nativeVirtualKey()),
                    KeyStates(keyEvent->nativeModifiers()),
                    keyEvent->nativeScanCode());
@@ -414,7 +400,7 @@ void FcitxModule::defaults() {
 
 void FcitxModule::runFcitx() {
     QProcess::startDetached(
-        QString::fromStdString(StandardPath::fcitxPath("bindir", "fcitx5")),
+        QString::fromStdString(StandardPaths::fcitxPath("bindir", "fcitx5")),
         QStringList());
 }
 
@@ -422,7 +408,7 @@ void FcitxModule::fixLayout() {
     const auto &imEntries = imConfig_->imEntries();
     if (imEntries.size() > 0 &&
         imEntries[0].key() !=
-            QString("keyboard-%0").arg(imConfig_->defaultLayout()) &&
+            QStringLiteral("keyboard-%0").arg(imConfig_->defaultLayout()) &&
         imEntries[0].key().startsWith("keyboard-")) {
         auto layoutString = imEntries[0].key().mid(9);
         imConfig_->setDefaultLayout(layoutString);
@@ -430,7 +416,7 @@ void FcitxModule::fixLayout() {
 }
 
 void FcitxModule::fixInputMethod() {
-    auto imname = QString("keyboard-%0").arg(imConfig_->defaultLayout());
+    auto imname = QStringLiteral("keyboard-%0").arg(imConfig_->defaultLayout());
     FcitxQtStringKeyValue imEntry;
     int i = 0;
     auto imEntries = imConfig_->imEntries();
