@@ -1,3 +1,7 @@
+function hasProperty(obj, key) {
+    return Object.prototype.hasOwnProperty.call(obj, key);
+}
+
 function getRawValue(rawValue, name) {
     if (name.length == 0) {
         return "";
@@ -6,7 +10,7 @@ function getRawValue(rawValue, name) {
         return "";
     }
     for (var i = 0; i < name.length; i++) {
-        if (rawValue.hasOwnProperty(name[i])) {
+        if (hasProperty(rawValue, name[i])) {
             rawValue = rawValue[name[i]];
         } else {
             return "";
@@ -20,7 +24,7 @@ function setRawValue(rawValue, name, value) {
         if (i + 1 == name.length) {
             rawValue[name[i]] = value;
         } else {
-            if (!rawValue.hasOwnProperty(name[i])) {
+            if (!hasProperty(rawValue, name[i])) {
                 rawValue[name[i]] = {};
             }
             rawValue = rawValue[name[i]];
