@@ -362,7 +362,7 @@ bool AddonProxyModel::lessThan(const QModelIndex &left,
 
     QString l = left.data(Qt::DisplayRole).toString();
     QString r = right.data(Qt::DisplayRole).toString();
-    return QCollator().compare(l, r) < 0;
+    return QString::localeAwareCompare(l, r) < 0;
 }
 
 void AddonProxyModel::setFilterText(const QString &text) {
@@ -373,6 +373,9 @@ void AddonProxyModel::setFilterText(const QString &text) {
 }
 
 void launchExternalConfig(const QString &uri, WId wid) {
+    if (uri.isEmpty()) {
+        return;
+    }
     QFileInfo pathToWrapper(FCITX5_QT_GUI_WRAPPER);
     QDir dirToWrapper = pathToWrapper.dir();
     if (uri.startsWith("fcitx://config/addon/")) {
@@ -418,6 +421,9 @@ void launchExternalConfig(const QString &uri, WId wid) {
     } else {
         // Assume this is a program path.
         QStringList args = QProcess::splitCommand(uri);
+        if (args.isEmpty()) {
+            return;
+        }
         QString program = args.takeFirst();
         QProcess::startDetached(program, args);
     }
