@@ -104,11 +104,7 @@ public:
                            index.parent(), index.row() - 1)) {
             return;
         }
-#if (QT_VERSION < QT_VERSION_CHECK(5, 13, 0))
-        values_.swap(index.row() - 1, index.row());
-#else
         values_.swapItemsAt(index.row() - 1, index.row());
-#endif
         endMoveRows();
     }
 
@@ -121,11 +117,7 @@ public:
                            index.parent(), index.row() + 2)) {
             return;
         }
-#if (QT_VERSION < QT_VERSION_CHECK(5, 13, 0))
-        values_.swap(index.row(), index.row() + 1);
-#else
         values_.swapItemsAt(index.row(), index.row() + 1);
-#endif
         endMoveRows();
     }
 
